diff --git a/change_log.txt b/change_log.txt
index 64ca59868c..e9dc5b6956 100644
--- a/change_log.txt
+++ b/change_log.txt
@@ -18,7 +18,7 @@ email address.
================================================================================
+pcbnew
refined the dialog_freeroute_exchange.pjd file, adding tooltips, wording
- changes, and added this comment also:
+ changes, wxID_CANCEL so ESC key closes, and added this comment also:
// @todo:
// 1) add freeroute.jnlp to the Kicad project
// 2) change this next C++ line simply run $ "javaws freeroute.jnlp" as a system
diff --git a/how-to-build-kicad.txt.deprecated b/how-to-build-kicad.txt
similarity index 100%
rename from how-to-build-kicad.txt.deprecated
rename to how-to-build-kicad.txt
diff --git a/pcbnew/dialog_freeroute_exchange.cpp b/pcbnew/dialog_freeroute_exchange.cpp
index 1b5e6a152f..e5dea052cf 100644
--- a/pcbnew/dialog_freeroute_exchange.cpp
+++ b/pcbnew/dialog_freeroute_exchange.cpp
@@ -66,6 +66,7 @@ IMPLEMENT_DYNAMIC_CLASS( dialog_freeroute_exchange, wxDialog )
BEGIN_EVENT_TABLE( dialog_freeroute_exchange, wxDialog )
////@begin dialog_freeroute_exchange event table entries
+ EVT_INIT_DIALOG( dialog_freeroute_exchange::OnInitDialog )
EVT_CLOSE( dialog_freeroute_exchange::OnCloseWindow )
EVT_BUTTON( ID_CREATE_EXPORT_DSN_FILE, dialog_freeroute_exchange::OnCreateExportDsnFileClick )
@@ -74,7 +75,7 @@ BEGIN_EVENT_TABLE( dialog_freeroute_exchange, wxDialog )
EVT_BUTTON( ID_IMPORT_FREEROUTE_DSN_FILE, dialog_freeroute_exchange::OnImportFreerouteDsnFileClick )
- EVT_BUTTON( wxID_CLOSE, dialog_freeroute_exchange::OnCloseClick )
+ EVT_BUTTON( wxID_CANCEL, dialog_freeroute_exchange::OnCancelClick )
EVT_BUTTON( ID_GOTO_FREEROUTE_WEB_SITE, dialog_freeroute_exchange::OnGotoFreerouteWebSiteClick )
@@ -168,7 +169,7 @@ void dialog_freeroute_exchange::Init()
void dialog_freeroute_exchange::CreateControls()
{
////@begin dialog_freeroute_exchange content construction
- // Generated by DialogBlocks, Tue 18 Mar 2008 16:15:58 CDT (unregistered)
+ // Generated by DialogBlocks, Wed 19 Mar 2008 00:26:30 CDT (unregistered)
dialog_freeroute_exchange* itemDialog1 = this;
@@ -193,34 +194,38 @@ void dialog_freeroute_exchange::CreateControls()
itemButton6->SetToolTip(_("Merge a session file created by FreeRouter with the current board."));
itemBoxSizer3->Add(itemButton6, 0, wxGROW|wxALL, 5);
- wxButton* itemButton7 = new wxButton( itemDialog1, wxID_CLOSE, _("&Close"), wxDefaultPosition, wxDefaultSize, 0 );
+ wxStdDialogButtonSizer* itemStdDialogButtonSizer7 = new wxStdDialogButtonSizer;
+
+ itemBoxSizer3->Add(itemStdDialogButtonSizer7, 0, wxGROW|wxALL, 5);
+ wxButton* itemButton8 = new wxButton( itemDialog1, wxID_CANCEL, _("&Close"), wxDefaultPosition, wxDefaultSize, 0 );
+ itemButton8->SetDefault();
+ itemStdDialogButtonSizer7->AddButton(itemButton8);
+
+ itemStdDialogButtonSizer7->Realize();
+
+ wxBoxSizer* itemBoxSizer9 = new wxBoxSizer(wxVERTICAL);
+ itemBoxSizer2->Add(itemBoxSizer9, 1, wxGROW|wxALL, 5);
+
+ wxButton* itemButton10 = new wxButton( itemDialog1, ID_GOTO_FREEROUTE_WEB_SITE, _("Visit the FreeRouting.net Website with your Browser"), wxDefaultPosition, wxDefaultSize, 0 );
if (dialog_freeroute_exchange::ShowToolTips())
- itemButton7->SetToolTip(_("Close this dialog window"));
- itemBoxSizer3->Add(itemButton7, 0, wxGROW|wxALL, 5);
+ itemButton10->SetToolTip(_("Launch your browser and go to the FreeRouting.net website"));
+ itemBoxSizer9->Add(itemButton10, 0, wxGROW|wxALL, 5);
- wxBoxSizer* itemBoxSizer8 = new wxBoxSizer(wxVERTICAL);
- itemBoxSizer2->Add(itemBoxSizer8, 1, wxGROW|wxALL, 5);
-
- wxButton* itemButton9 = new wxButton( itemDialog1, ID_GOTO_FREEROUTE_WEB_SITE, _("Visit the FreeRouting.net Website with your Browser"), wxDefaultPosition, wxDefaultSize, 0 );
- if (dialog_freeroute_exchange::ShowToolTips())
- itemButton9->SetToolTip(_("Launch your browser and go to the FreeRouting.net website"));
- itemBoxSizer8->Add(itemButton9, 0, wxGROW|wxALL, 5);
-
- wxStaticText* itemStaticText10 = new wxStaticText( itemDialog1, wxID_STATIC, _("FreeRouting.net URL"), wxDefaultPosition, wxDefaultSize, 0 );
- itemBoxSizer8->Add(itemStaticText10, 0, wxGROW|wxLEFT|wxRIGHT|wxTOP, 5);
+ wxStaticText* itemStaticText11 = new wxStaticText( itemDialog1, wxID_STATIC, _("FreeRouting.net URL"), wxDefaultPosition, wxDefaultSize, 0 );
+ itemBoxSizer9->Add(itemStaticText11, 0, wxGROW|wxLEFT|wxRIGHT|wxTOP, 5);
m_FreerouteURLName = new wxTextCtrl( itemDialog1, ID_TEXT_EDIT_FR_URL, _T(""), wxDefaultPosition, wxDefaultSize, 0 );
if (dialog_freeroute_exchange::ShowToolTips())
m_FreerouteURLName->SetToolTip(_("The URL of the FreeRouting.net website"));
- itemBoxSizer8->Add(m_FreerouteURLName, 1, wxGROW|wxLEFT|wxRIGHT|wxBOTTOM, 5);
+ itemBoxSizer9->Add(m_FreerouteURLName, 1, wxGROW|wxLEFT|wxRIGHT|wxBOTTOM, 5);
- wxStaticText* itemStaticText12 = new wxStaticText( itemDialog1, wxID_STATIC, _("FreeRouting.net Command"), wxDefaultPosition, wxDefaultSize, 0 );
- itemBoxSizer8->Add(itemStaticText12, 0, wxGROW|wxLEFT|wxRIGHT|wxTOP, 5);
+ wxStaticText* itemStaticText13 = new wxStaticText( itemDialog1, wxID_STATIC, _("FreeRouting.net Command"), wxDefaultPosition, wxDefaultSize, 0 );
+ itemBoxSizer9->Add(itemStaticText13, 0, wxGROW|wxLEFT|wxRIGHT|wxTOP, 5);
m_FreerouteURLCommandString = new wxTextCtrl( itemDialog1, ID_TEXT_EDIT_FR_CMD, _T(""), wxDefaultPosition, wxDefaultSize, 0 );
if (dialog_freeroute_exchange::ShowToolTips())
m_FreerouteURLCommandString->SetToolTip(_("The URL of the JNLP file which Java Web Start uses to launch the FreeRouter"));
- itemBoxSizer8->Add(m_FreerouteURLCommandString, 1, wxGROW|wxLEFT|wxRIGHT|wxBOTTOM, 5);
+ itemBoxSizer9->Add(m_FreerouteURLCommandString, 1, wxGROW|wxLEFT|wxRIGHT|wxBOTTOM, 5);
////@end dialog_freeroute_exchange content construction
@@ -331,9 +336,10 @@ void dialog_freeroute_exchange::OnGotoFreerouteWebSiteClick( wxCommandEvent& eve
* wxEVT_COMMAND_BUTTON_CLICKED event handler for wxID_CLOSE
*/
-void dialog_freeroute_exchange::OnCloseClick( wxCommandEvent& event )
+void dialog_freeroute_exchange::OnCancelClick( wxCommandEvent& event )
{
- Close();
+ D(printf("OnCancelClick\n");)
+ Close( true );
}
@@ -343,6 +349,8 @@ void dialog_freeroute_exchange::OnCloseClick( wxCommandEvent& event )
void dialog_freeroute_exchange::OnCloseWindow( wxCloseEvent& event )
{
+ D(printf("OnCloseWindow\n");)
+
if( m_FreeRouteSetupChanged ) // Save new config
{
m_Parent->m_Parent->m_EDA_Config->Write( FREEROUTE_URL_KEY,
@@ -351,7 +359,7 @@ void dialog_freeroute_exchange::OnCloseWindow( wxCloseEvent& event )
m_FreerouteURLCommandString->GetValue() );
}
- event.Skip();
+ Destroy();
}
@@ -373,3 +381,17 @@ void dialog_freeroute_exchange::OnTextEditFrCmdUpdated( wxCommandEvent& event )
{
m_FreeRouteSetupChanged = true;
}
+
+
+/*!
+ * wxEVT_INIT_DIALOG event handler for ID_DIALOG_FREEROUTE_EXCHANGE
+ */
+
+void dialog_freeroute_exchange::OnInitDialog( wxInitDialogEvent& event )
+{
+////@begin wxEVT_INIT_DIALOG event handler for ID_DIALOG_FREEROUTE_EXCHANGE in dialog_freeroute_exchange.
+ // Before editing this code, remove the block markers.
+ event.Skip();
+////@end wxEVT_INIT_DIALOG event handler for ID_DIALOG_FREEROUTE_EXCHANGE in dialog_freeroute_exchange.
+}
+
diff --git a/pcbnew/dialog_freeroute_exchange.pjd b/pcbnew/dialog_freeroute_exchange.pjd
index fb204fb580..78be3ef73b 100644
--- a/pcbnew/dialog_freeroute_exchange.pjd
+++ b/pcbnew/dialog_freeroute_exchange.pjd
@@ -128,7 +128,7 @@
0
""
1
- 0
+ -8519680
""
"Debug"
"ANSI"
@@ -214,7 +214,8 @@
0
0
"m_FreeRouteSetupChanged|bool|FreeRouteSetupChanged|false|2|0|Flag set to true if Freeroute config changed"
- "wxEVT_CLOSE_WINDOW|OnCloseWindow|NONE||"
+ "wxEVT_INIT_DIALOG|OnInitDialog|NONE||dialog_freeroute_exchange"
+ "wxEVT_CLOSE_WINDOW|OnCloseWindow|NONE||"
"ID_DIALOG_FREEROUTE_EXCHANGE"
10000
"dialog_freeroute_exchange"
@@ -245,7 +246,7 @@
0
1
1
- 1
+ 0
0
0
1
@@ -518,58 +519,25 @@
""
- "wxButton: wxID_CLOSE"
+ "wxStdDialogButtonSizer"
"dialog-control-document"
""
- "dialogcontrol"
+ "sizer"
0
1
0
0
- "14/3/2008"
- "wbButtonProxy"
- "wxEVT_COMMAND_BUTTON_CLICKED|OnCloseClick|NONE||dialog_freeroute_exchange"
- "wxID_CLOSE"
- 5001
- ""
- "wxButton"
- "wxButton"
- 1
- 0
- ""
- ""
+ "18/3/2008"
+ "wbStdDialogButtonSizerProxy"
+ 0
+ 1
+ 0
+ 0
+ 0
+ 0
+ 0
+ 0
""
- "&Close"
- 0
- ""
- "Close this dialog window"
- ""
- ""
- ""
- ""
- ""
- ""
- ""
- ""
- ""
- ""
- 0
- 1
- "<Any platform>"
- 0
- 0
- 0
- 0
- 0
- 0
- 0
- 0
- 0
- ""
- -1
- -1
- -1
- -1
"Expand"
"Centre"
0
@@ -581,8 +549,74 @@
0
0
0
- ""
- ""
+ "<Any platform>"
+
+ "wxButton: wxID_CANCEL"
+ "dialog-control-document"
+ ""
+ "dialogcontrol"
+ 0
+ 1
+ 0
+ 1
+ "18/3/2008"
+ "wbButtonProxy"
+ "wxEVT_COMMAND_BUTTON_CLICKED|OnCancelClick|NONE||dialog_freeroute_exchange"
+ "wxID_CANCEL"
+ 5101
+ ""
+ "wxButton"
+ "wxButton"
+ 1
+ 0
+ ""
+ ""
+ ""
+ "&Close"
+ 1
+ ""
+ ""
+ ""
+ ""
+ ""
+ ""
+ ""
+ ""
+ ""
+ ""
+ ""
+ ""
+ 0
+ 1
+ "<Any platform>"
+ 0
+ 0
+ 0
+ 0
+ 0
+ 0
+ 0
+ 0
+ 0
+ ""
+ -1
+ -1
+ -1
+ -1
+ "Expand"
+ "Centre"
+ 0
+ 5
+ 1
+ 1
+ 1
+ 1
+ 0
+ 0
+ 0
+ ""
+ ""
+
diff --git a/pcbnew/dialog_freeroute_exchange.h b/pcbnew/dialog_freeroute_exchange.h
index 2650a3bf92..1270477ff3 100644
--- a/pcbnew/dialog_freeroute_exchange.h
+++ b/pcbnew/dialog_freeroute_exchange.h
@@ -42,7 +42,7 @@
#define ID_GOTO_FREEROUTE_WEB_SITE 10004
#define ID_TEXT_EDIT_FR_URL 10005
#define ID_TEXT_EDIT_FR_CMD 10006
-#define SYMBOL_DIALOG_FREEROUTE_EXCHANGE_STYLE wxCAPTION|wxRESIZE_BORDER|wxSYSTEM_MENU|wxCLOSE_BOX|wxTAB_TRAVERSAL
+#define SYMBOL_DIALOG_FREEROUTE_EXCHANGE_STYLE wxCAPTION|wxRESIZE_BORDER|wxCLOSE_BOX|wxTAB_TRAVERSAL
#define SYMBOL_DIALOG_FREEROUTE_EXCHANGE_TITLE _("dialog_freeroute_exchange")
#define SYMBOL_DIALOG_FREEROUTE_EXCHANGE_IDNAME ID_DIALOG_FREEROUTE_EXCHANGE
#define SYMBOL_DIALOG_FREEROUTE_EXCHANGE_SIZE wxSize(400, 300)
@@ -78,6 +78,9 @@ public:
////@begin dialog_freeroute_exchange event handler declarations
+ /// wxEVT_INIT_DIALOG event handler for ID_DIALOG_FREEROUTE_EXCHANGE
+ void OnInitDialog( wxInitDialogEvent& event );
+
/// wxEVT_CLOSE_WINDOW event handler for ID_DIALOG_FREEROUTE_EXCHANGE
void OnCloseWindow( wxCloseEvent& event );
@@ -90,8 +93,8 @@ public:
/// wxEVT_COMMAND_BUTTON_CLICKED event handler for ID_IMPORT_FREEROUTE_DSN_FILE
void OnImportFreerouteDsnFileClick( wxCommandEvent& event );
- /// wxEVT_COMMAND_BUTTON_CLICKED event handler for wxID_CLOSE
- void OnCloseClick( wxCommandEvent& event );
+ /// wxEVT_COMMAND_BUTTON_CLICKED event handler for wxID_CANCEL
+ void OnCancelClick( wxCommandEvent& event );
/// wxEVT_COMMAND_BUTTON_CLICKED event handler for ID_GOTO_FREEROUTE_WEB_SITE
void OnGotoFreerouteWebSiteClick( wxCommandEvent& event );